export interface NetworkProps {
	testID?: string
}
